@@ -1,22 +1,19 @@
-from zope.i18nmessageid import MessageFactory
-
 from z3c.form.interfaces import INPUT_MODE
 from z3c.form import form as z3cform, field as z3cfield
 from z3c.form import button
-from z3c.form import field, group as z3cgroup
-from z3c.formwidget.query.widget import QuerySourceFieldRadioWidget
+from z3c.form import group as z3cgroup
 from z3c.form.browser.orderedselect import OrderedSelectWidget
 from z3c.form.widget import FieldWidget
 from z3c.form.browser import widget
 
 from Products.CMFCore.utils import getToolByName
 from Products.CMFPlone import PloneMessageFactory as plMF
+from plone.formwidget.contenttree import ContentTreeFieldWidget
 from plone.z3cform.layout import wrap_form
-from plone.z3cform.fieldsets import group, extensible
+from plone.z3cform.fieldsets import extensible
 
 from Solgema.fullcalendar.interfaces import ISolgemaFullcalendarProperties
-from Solgema.fullcalendar.widgets.widgets import ColorDictInputFieldWidget
-from Solgema.fullcalendar.config import _
+from Solgema.fullcalendar import msg_fact as _
 
 
 class CriteriasOrderedSelectWidget(OrderedSelectWidget):
@@ -40,12 +37,13 @@ def CriteriasOrderedSelectFieldWidget(field, request):
 
 class CalendarGroup(z3cgroup.Group):
     label = _(u'Calendar', default="Calendar")
-    
+
     fields = z3cfield.Fields( ISolgemaFullcalendarProperties ).select(
         'slotMinutes',
         'allDaySlot',
         'defaultCalendarView',
         'shortDayNameFormat',
+        'headerLeft',
         'headerRight',
         'weekends',
         'firstDay',
@@ -53,12 +51,18 @@ class CalendarGroup(z3cgroup.Group):
         'firstHour',
         'minTime',
         'maxTime',
+        'gcalSources',
         'target_folder',
         'calendarHeight',
-        'displayNoscriptList')
-    fields['target_folder'].widgetFactory[INPUT_MODE] = QuerySourceFieldRadioWidget
+        'displayNoscriptList',
+        'disableAJAX',
+        'caleditable',
+        'disableDragging',
+        'disableResizing',
+        'eventType')
+    fields['target_folder'].widgetFactory[INPUT_MODE] = ContentTreeFieldWidget
 
-class QueryGroup(z3cgroup.Group):
+class TopicQueryGroup(z3cgroup.Group):
     label = _(u'Query', default="Query")
 
     fields = z3cfield.Fields( ISolgemaFullcalendarProperties ).select(
@@ -67,22 +71,22 @@ class QueryGroup(z3cgroup.Group):
         'overrideStateForAdmin')
     fields['availableCriterias'].widgetFactory[INPUT_MODE] = CriteriasOrderedSelectFieldWidget
 
+class FolderQueryGroup(z3cgroup.Group):
+    label = _(u'Sub-Folders', default="Sub-Folders")
+
+    fields = z3cfield.Fields( ISolgemaFullcalendarProperties ).select(
+        'availableSubFolders',)
+    fields['availableSubFolders'].widgetFactory[INPUT_MODE] = CriteriasOrderedSelectFieldWidget
+
 class ColorsGroup(z3cgroup.Group):
     label = _(u'Colors', default="Colors")
 
-    fields = z3cfield.Fields( ISolgemaFullcalendarProperties ).select(
-        'queryColors')
-    fields['queryColors'].widgetFactory[INPUT_MODE] = ColorDictInputFieldWidget
+    fields = z3cfield.Fields(ISolgemaFullcalendarProperties).select(
+            'queryColors')
 
 
-class SolgemaFullcalendarFormBase(extensible.ExtensibleForm, z3cform.EditForm ):
-
-#    fields = z3cfield.Fields( ISolgemaFullcalendarProperties )
-#    fields['target_folder'].widgetFactory[INPUT_MODE] = QuerySourceFieldRadioWidget
-#    fields['availableCriterias'].widgetFactory[INPUT_MODE] = CriteriasOrderedSelectFieldWidget
-#    fields['queryColors'].widgetFactory[INPUT_MODE] = ColorDictInputFieldWidget
-
-    groups = (CalendarGroup, QueryGroup, ColorsGroup)
+class SolgemaFullcalendarFormBase(extensible.ExtensibleForm, z3cform.EditForm):
+    groups = (CalendarGroup, FolderQueryGroup, ColorsGroup)
 
     @button.buttonAndHandler(plMF('label_save', default=u'Save'), name='apply')
     def handleApply(self, action):
@@ -97,12 +101,16 @@ class SolgemaFullcalendarFormBase(extensible.ExtensibleForm, z3cform.EditForm ):
             self.status = self.successMessage
         else:
             self.status = self.noChangesMessage
-        self.request.RESPONSE.redirect( self.context.absolute_url() )
+        self.request.RESPONSE.redirect(self.context.absolute_url())
 
     @button.buttonAndHandler(plMF('label_cancel', default=u'Cancel'),
                              name='cancel')
     def handleCancel( self, action):
-        self.request.RESPONSE.redirect( self.context.absolute_url() )
+        self.request.RESPONSE.redirect(self.context.absolute_url())
 
 SolgemaFullcalendarForm = wrap_form(SolgemaFullcalendarFormBase)
 
+class SolgemaFullcalendarTopicFormBase(SolgemaFullcalendarFormBase):
+    groups = (CalendarGroup, TopicQueryGroup, ColorsGroup)
+
+SolgemaFullcalendarTopicForm = wrap_form(SolgemaFullcalendarTopicFormBase)
